@@ -21,6 +21,20 @@ test_that('Two class - Powers paper', {
   )
 })
 
+# ------------------------------------------------------------------------------
+
+test_that("'micro' `NA` case is handled correctly", {
+
+  truth <- factor(c(rep("a", 2), rep("b", 2)))
+  estimate <- factor(rep("b", length(truth)), levels(truth))
+
+  expect_equal(
+    precision_vec(truth, estimate, estimator = "micro"),
+    NA_real_
+  )
+
+})
+
 # sklearn compare --------------------------------------------------------------
 
 py_res <- read_pydata("py-precision")
